<p>
    <a href="https://sylius.com" target="_blank">
        <img src="https://demo.sylius.com/assets/shop/img/logo.png" />
    </a>
</p>

# Installation
`composer require dedi/sylius-taxon-type-plugin`

Change your `config/bundles.php` file to add these lines for the plugin :

```php
   <?php
   
   return [
       //..
       Dedi\SyliusTaxonTypePlugin\DediSyliusTaxonTypePlugin::class => ['all' => true],
];
```

Import routing in your `config/routes.yaml` file:
```yaml
# config/routes.yaml

dedi_sylius_taxon_type_admin:
    resource: "@DediSyliusTaxonTypePlugin/Resources/config/admin_routing.yml"
    prefix: /admin
```

Import ui config in your `config/packages/sylius_ui.yaml` file:

```yaml
# config/packages/sylius_ui.yaml

imports:
    ...
        
    - { resource: "@DediSyliusTaxonTypePlugin/Resources/config/packages/sylius_ui.yaml" }
```

In your TaxonInterface, extends the following:
```php
use Dedi\SyliusTaxonTypePlugin\Model\TaxonInterface as DediSyliusTaxonTypePluginTaxonInterface;

interface TaxonInterface extends DediSyliusTaxonTypePluginTaxonInterface
{
    //...
}
```

In your Taxon class, add the following:
```php
use Sylius\Component\Core\Model\Taxon as BaseTaxon;

/**
 * @ORM\Entity
 * @ORM\Table(name="sylius_taxon")
 */
class Taxon extends BaseTaxon implements TaxonInterface
{
    use TaxonTypeTrait;
    
    use ProductAwareTrait {
        ProductAwareTrait::__construct as private __productAwareTraitConstruct;
    }

    public function __construct()
    {
        parent::__construct();

        $this->__productAwareTraitConstruct();
    }
    //...
}
```

In your ProductInterface, extends the following:

```php
use Dedi\SyliusTaxonTypePlugin\Model\ProductAwareInterface as DediSyliusTaxonTypePluginProductInterface;

interface ProductInterface extends DediSyliusTaxonTypePluginProductInterface
{
    //...
}
```


In your Product class, add the following:
```php
use Sylius\Component\Core\Model\Product as BaseProduct;

/**
 * @ORM\Entity
 * @ORM\Table(name="sylius_product")
 */
class Product extends BaseProduct implements ProductInterface
{
    use BrandAwareTrait;
    //...
}
```

Import config in your `config/packages/_sylius.yaml` file:
```yaml
# config/packages/_sylius.yaml

imports:
      ...

    - { resource: "@DediSyliusTaxonTypePlugin/Resources/config/grids/brand_grid.yaml" }
    - { resource: "@DediSyliusTaxonTypePlugin/Resources/config/grids/sylius_admin_product.yaml" }

sylius_taxonomy:
    resources:
        taxon:
            classes:
                model: Path\To\Your\Entity\Taxon
                interface: Path\To\Your\Entity\TaxonInterface
                repository: Dedi\SyliusTaxonTypePlugin\Repository\TaxonRepository
sylius_product:
    resources:
        product:
            classes:
                model: Path\To\Your\Entity\Product
                interface: Path\To\Your\Entity\ProductInterface

```

Then migrate your database 
```bash
$ bin/console doctrine:migrations:diff
$ bin/console doctrine:migrations:migrate
```

Override file @SyliusAdminBundle/Taxon/_form.html.twig and add :
```twig
<div class="two fields">
    {{ form_row(form.enabled) }}
</div>
{{ form_row(form.type) }}
```
Override file @SyliusAdminBundle/Taxon/_treeWithButtons.html.twig and update this line :
```twig
{% for taxon in taxons|filter(taxon => taxon.id is not null and taxon.type == constant('Dedi\\SyliusTaxonTypePlugin\\Model\\TypedTaxonInterface::DEFAULT_TYPE')) %}
```